@@ -39,7 +39,7 @@ int fio_pin_memory(void)
 	if (phys_mem) {
 		if ((mlock_size + 128 * 1024 * 1024) > phys_mem) {
 			mlock_size = phys_mem - 128 * 1024 * 1024;
-			log_info("fio: limiting mlocked memory to %lluMiB\n",
+			log_info("fio: limiting mlocked memory to %lluMB\n",
 							mlock_size >> 20);
 		}
 	}
@@ -65,8 +65,12 @@ static int alloc_mem_shm(struct thread_data *td, unsigned int total_mem)
 {
 	int flags = IPC_CREAT | SHM_R | SHM_W;
 
-	if (td->o.mem_type == MEM_SHMHUGE)
+	if (td->o.mem_type == MEM_SHMHUGE) {
+		unsigned long mask = td->o.hugepage_size - 1;
+
 		flags |= SHM_HUGETLB;
+		total_mem = (total_mem + mask) & ~mask;
+	}
 
 	td->shm_id = shmget(IPC_PRIVATE, total_mem, flags);
 	dprint(FD_MEM, "shmget %u, %d\n", total_mem, td->shm_id);
